/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.push.notifications.web.internal.util;

import com.liferay.osgi.service.tracker.collections.map.ServiceTrackerMap;
import com.liferay.osgi.service.tracker.collections.map.ServiceTrackerMapFactory;
import com.liferay.portal.kernel.resource.bundle.AggregateResourceBundleLoader;
import com.liferay.portal.kernel.resource.bundle.ResourceBundleLoader;
import com.liferay.portal.kernel.resource.bundle.ResourceBundleLoaderUtil;
import com.liferay.push.notifications.sender.PushNotificationsSender;

import org.osgi.framework.Bundle;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import org.osgi.service.component.annotations.Activate;
import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Deactivate;
import org.osgi.util.tracker.ServiceTrackerCustomizer;

/**
 * @author Andrea Di Giorgi
 */
@Component(service = ResourceBundleLoaderProvider.class)
public class ResourceBundleLoaderProvider {

	public ResourceBundleLoader getResourceBundleLoader(String platform) {
		ResourceBundleLoader resourceBundleLoader =
			_serviceTrackerMap.getService(platform);

		if (resourceBundleLoader == null) {
			return ResourceBundleLoaderUtil.getPortalResourceBundleLoader();
		}

		return new AggregateResourceBundleLoader(
			resourceBundleLoader,
			ResourceBundleLoaderUtil.getPortalResourceBundleLoader());
	}

	@Activate
	protected void activate(BundleContext bundleContext) {
		_serviceTrackerMap = ServiceTrackerMapFactory.openSingleValueMap(
			bundleContext, PushNotificationsSender.class, "platform",
			new ServiceTrackerCustomizer
				<PushNotificationsSender, ResourceBundleLoader>() {

				@Override
				public ResourceBundleLoader addingService(
					ServiceReference<PushNotificationsSender>
						serviceReference) {

					Bundle bundle = serviceReference.getBundle();

					return ResourceBundleLoaderUtil.
						getResourceBundleLoaderByBundleSymbolicName(
							bundle.getSymbolicName());
				}

				@Override
				public void modifiedService(
					ServiceReference<PushNotificationsSender> serviceReference,
					ResourceBundleLoader resourceBundleLoader) {
				}

				@Override
				public void removedService(
					ServiceReference<PushNotificationsSender> serviceReference,
					ResourceBundleLoader resourceBundleLoader) {
				}

			});
	}

	@Deactivate
	protected void deactivate() {
		_serviceTrackerMap.close();
	}

	private ServiceTrackerMap<String, ResourceBundleLoader> _serviceTrackerMap;

}